@@ -488,6 +488,77 @@ gboolean on_window1_delete_event(GtkWidget * widget, GdkEvent * event,
 	return FALSE;
 }
 
+int g_do_run_cmds(char *cmd, int restart)
+{
+	GtkWidget *dialog, *label; int r = 0;
+	gint result; char b[1024];
+	execute_sym_question(cmd, b, restart, 0);
+
+	dialog = gtk_dialog_new_with_buttons(_("Execution:"),
+					     GTK_WINDOW(main_wnd),
+					     (GtkDialogFlags)
+					     (GTK_DIALOG_MODAL |
+					      GTK_DIALOG_DESTROY_WITH_PARENT),
+					     GTK_STOCK_OK,
+					     GTK_RESPONSE_YES,
+					     GTK_STOCK_NO,
+					     GTK_RESPONSE_NO,
+					     GTK_STOCK_CANCEL,
+					     GTK_RESPONSE_CANCEL, NULL);
+	gtk_dialog_set_default_response(GTK_DIALOG(dialog),
+					GTK_RESPONSE_CANCEL);
+
+	label = gtk_label_new(_(b));
+	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), label);
+	gtk_widget_show(label);
+
+	result = gtk_dialog_run(GTK_DIALOG(dialog));
+
+	switch (result) {
+	case GTK_RESPONSE_YES:
+		r = 1; break;
+	case GTK_RESPONSE_NO:
+		r = -1; break;
+	case GTK_RESPONSE_CANCEL:
+	case GTK_RESPONSE_DELETE_EVENT:
+	default:
+		break;
+	}
+
+	gtk_widget_destroy(dialog);
+	return r;
+}
+
+int show_intro(void)
+{
+	GtkWidget *dialog, *label; int r = 0;
+	gint result; 
+
+	dialog = gtk_dialog_new_with_buttons(_("Execution:"),
+					     GTK_WINDOW(main_wnd),
+					     (GtkDialogFlags)
+					     (GTK_DIALOG_MODAL |
+					      GTK_DIALOG_DESTROY_WITH_PARENT),
+					     GTK_STOCK_OK,
+					     GTK_RESPONSE_YES,
+					     NULL);
+	gtk_dialog_set_default_response(GTK_DIALOG(dialog),
+					GTK_RESPONSE_CANCEL);
+
+	label = gtk_label_new(_("Note: Commands can be executed from within the configuratior now\n"
+		     "by double-clicking on \"Execute ...\" configuration entries.\n"
+		     "It is not neccessary any more to exit the GUI for \ni.e. \"install/upgrade\" and \"build\".\n"
+				"The LINUX and BUILDROOT configuration trees are accessible\n"
+		     "as subtrees in this configurator.\n"));
+	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), label);
+	gtk_widget_show(label);
+
+	result = gtk_dialog_run(GTK_DIALOG(dialog));
+
+	gtk_widget_destroy(dialog);
+	return r;
+}
+
 
 void on_window1_destroy(GtkObject * object, gpointer user_data)
 {
@@ -873,6 +944,7 @@ static void change_sym_value(struct menu *menu, gint col)
 	case S_INT:
 	case S_HEX:
 	case S_STRING:
+	case S_EXECUTE:
 	default:
 		break;
 	}
@@ -973,7 +1045,10 @@ on_treeview2_button_press_event(GtkWidget * widget,
 		enum prop_type ptype;
 		ptype = menu->prompt ? menu->prompt->type : P_UNKNOWN;
 
-		if (ptype == P_MENU && view_mode != FULL_VIEW && col == COL_OPTION) {
+		if (menu->sym && (sym_get_type(menu->sym) == S_EXECUTE) &&
+		    (col == COL_OPTION || col == COL_VALUE || col == COL_NAME)) {
+			execute_sym(menu->sym, 0);
+		} else if (ptype == P_MENU && view_mode != FULL_VIEW && col == COL_OPTION) {
 			// goes down into menu
 			current = menu;
 			display_tree_part();
@@ -1209,6 +1284,7 @@ static gchar **fill_row(struct menu *menu)
 		break;
 	case S_INT:
 	case S_HEX:
+	case S_EXECUTE:
 	case S_STRING:
 		def = sym_get_string_value(sym);
 		row[COL_VALUE] = g_strdup(def);
@@ -1525,7 +1601,7 @@ int main(int ac, char *av[])
 	/* Determine GUI path */
 	env = getenv(SRCTREE);
 	if (env)
-		glade_file = g_strconcat(env, "/gaisler/config/gconf.glade", NULL);
+		glade_file = g_strconcat(env, "/gaisler/kconfig/gconf.glade", NULL);
 	else if (av[0][0] == '/')
 		glade_file = g_strconcat(av[0], ".glade", NULL);
 	else
@@ -1567,10 +1643,12 @@ int main(int ac, char *av[])
 		display_tree(&rootmenu);
 		break;
 	}
-
+	show_intro();
+	
+	f_do_run_cmds = g_do_run_cmds;
 	gtk_main();
 
-	return 0;
+	return get_restart();
 }
 
 static void conf_changed(void)
