@@ -451,11 +451,13 @@ bool menu_is_visible(struct menu *menu)
 
 const char *menu_get_prompt(struct menu *menu)
 {
+	char *m = 0;
 	if (menu->prompt)
-		return menu->prompt->text;
+		m = menu->prompt->text;
 	else if (menu->sym)
-		return menu->sym->name;
-	return NULL;
+		m = menu->sym->name;
+	m = resolve_vars(m, menu->level);
+	return m;
 }
 
 struct menu *menu_get_root_menu(struct menu *menu)
